@@ -4,7 +4,6 @@ from pathlib import Path
 from typing import Dict
 
 import pandas as pd
-from cognite.client import CogniteClient
 from cognite.client.data_classes import Asset, AssetUpdate
 from pandas import DataFrame
 
@@ -24,12 +23,7 @@ class ModelAssetHierarchy:
         self.airInfra = airInfra
         project_info = const.AUTHENTICATION[project]
         print("Project: " + project_info.name)
-        self.client = CogniteClient(
-            api_key=project_info.get_client_api_key(),
-            project=project_info.name,
-            client_name="AIR Model Asset Client",
-            base_url=project_info.base_url,
-        )
+        self.client = cdf.experimental_client(project)
         self._hierarchy: Dict[str, Dict] = {}
         self._existing_hierarchy: DataFrame = pd.DataFrame()
         self._data_set_id: int = 0
