@@ -48,11 +48,14 @@ def await_function_deployment(client: ExperimentalClient, function_name: str, ma
     t_end = time.time() + max_wait
     while time.time() < t_end:
         function = client.functions.retrieve(external_id=function_name)
-        print(f"Function status {function.status}")
-        if function.status == "Ready":
-            return True
-        if function.status == "Failed":
-            return False
+        if function is not None:
+            print(f"Function status {function.status}")
+            if function.status == "Ready":
+                return True
+            if function.status == "Failed":
+                return False
+        else:
+            print(f"API returns None for {function_name}")
         time.sleep(5.0)
 
     return False
